==> rubocop_0.74.0%2Bdfsg.orig.tar.xz: rubocop-0.74.0/spec/rubocop/cop/layout/space_after_method_name_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::Cop::Layout::SpaceAfterMethodName do
  subject(:cop) { described_class.new }

  it 'registers an offense for def with space before the parenthesis' do
    expect_offense(<<~RUBY)
      def func (x)
              ^ Do not put a space between a method name and the opening parenthesis.
        a
      end
    RUBY
  end

  it 'registers offense for class def with space before parenthesis' do
    expect_offense(<<~RUBY)
      def self.func (x)
                   ^ Do not put a space between a method name and the opening parenthesis.
        a
      end
    RUBY
  end

  it 'registers offense for assignment def with space before parenthesis' do
    expect_offense(<<~RUBY)
      def func= (x)
               ^ Do not put a space between a method name and the opening parenthesis.
        a
      end
    RUBY
  end

  it 'accepts a def without arguments' do
    expect_no_offenses(<<~RUBY)
      def func
        a
      end
    RUBY
  end

  it 'accepts a defs without arguments' do
    expect_no_offenses(<<~RUBY)
      def self.func
        a
      end
    RUBY
  end

  it 'accepts a def with arguments but no parentheses' do
    expect_no_offenses(<<~RUBY)
      def func x
        a
      end
    RUBY
  end

  it 'accepts class method def with arguments but no parentheses' do
    expect_no_offenses(<<~RUBY)
      def self.func x
        a
      end
    RUBY
  end

  it 'accepts an assignment def with arguments but no parentheses' do
    expect_no_offenses(<<~RUBY)
      def func= x
        a
      end
    RUBY
  end

  it 'auto-corrects unwanted space' do
    new_source = autocorrect_source(<<~RUBY)
      def func (x)
        a
      end
      def self.func (x)
        a
      end
      def func= (x)
        a
      end
    RUBY
    expect(new_source).to eq(<<~RUBY)
      def func(x)
        a
      end
      def self.func(x)
        a
      end
      def func=(x)
        a
      end
    RUBY
  end
end

==> rubocop_0.80.1%2Bdfsg.orig.tar.xz: rubocop-0.80.1/spec/rubocop/cop/layout/space_after_method_name_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::Cop::Layout::SpaceAfterMethodName do
  subject(:cop) { described_class.new }

  it 'registers an offense and corrects def with space ' \
    'before the parenthesis' do
    expect_offense(<<~RUBY)
      def func (x)
              ^ Do not put a space between a method name and the opening parenthesis.
        a
      end
    RUBY

    expect_correction(<<~RUBY)
      def func(x)
        a
      end
    RUBY
  end

  it 'registers offense and corrects class def with space before parenthesis' do
    expect_offense(<<~RUBY)
      def self.func (x)
                   ^ Do not put a space between a method name and the opening parenthesis.
        a
      end
    RUBY

    expect_correction(<<~RUBY)
      def self.func(x)
        a
      end
    RUBY
  end

  it 'registers offense and corrects assignment def with space ' \
    'before parenthesis' do
    expect_offense(<<~RUBY)
      def func= (x)
               ^ Do not put a space between a method name and the opening parenthesis.
        a
      end
    RUBY

    expect_correction(<<~RUBY)
      def func=(x)
        a
      end
    RUBY
  end

  it 'accepts a def without arguments' do
    expect_no_offenses(<<~RUBY)
      def func
        a
      end
    RUBY
  end

  it 'accepts a defs without arguments' do
    expect_no_offenses(<<~RUBY)
      def self.func
        a
      end
    RUBY
  end

  it 'accepts a def with arguments but no parentheses' do
    expect_no_offenses(<<~RUBY)
      def func x
        a
      end
    RUBY
  end

  it 'accepts class method def with arguments but no parentheses' do
    expect_no_offenses(<<~RUBY)
      def self.func x
        a
      end
    RUBY
  end

  it 'accepts an assignment def with arguments but no parentheses' do
    expect_no_offenses(<<~RUBY)
      def func= x
        a
      end
    RUBY
  end
end
